@@ -17,8 +17,9 @@ sub body_contains {
 sub body_size { croak 'Method "body_size" not implemented by subclass' }
 
 sub boundary {
-  my $type = shift->headers->content_type || '';
-  $type =~ m!multipart.*boundary="?([a-zA-Z0-9'(),.:?\-_+/]+)!i and return $1;
+  return undef unless my $type = shift->headers->content_type;
+  $type =~ m!multipart.*boundary=(?:"([^"]+)"|([\w'(),.:?\-+/]+))!i
+    and return $1 // $2;
   return undef;
 }
 
